@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2005 by Joshua Keel <joshuakeel@gmail.com>              *
- *             (C) 2007 by Jeremy Whiting <jpwhiting@kde.org>              *
+ *             (C) 2007-2014 by Jeremy Whiting <jpwhiting@kde.org>         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,54 +20,54 @@
 
 #include "mainsettings.h"
 
-#include <kdebug.h>
-#include <kconfig.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kconfigdialog.h>
-#include <kmessagebox.h>
+#include <KConfig>
+#include <KConfigDialog>
+#include <KLocalizedString>
+#include <KMessageBox>
+
+#include <QPushButton>
+#include <QStandardPaths>
+#include <QLoggingCategory>
 
 #include <sharedkvtmlfiles.h>
-#include <kanagramsettings.h>
+#include "kanagramsettings.h"
+#include "kanagramgame.h"
+
+Q_DECLARE_LOGGING_CATEGORY(KANAGRAM)
 
 MainSettings::MainSettings(QWidget *parent) : QWidget(parent)
 {
     setupUi( this );
-    m_parent = (KConfigDialog*)parent;
+
     slotToggleAdvancedSettings();
-    connect(parent, SIGNAL(applyClicked()), this, SLOT(slotUpdateLanguage()));
-    connect(parent, SIGNAL(okClicked()), this, SLOT(slotUpdateLanguage()));
-    connect(languageComboBox, SIGNAL(activated(int)), this, SLOT(slotSetDirty()));
-    connect(scoringOptions,SIGNAL(toggled(bool)),this,SLOT(slotToggleAdvancedSettings()));
     populateLanguageBox();
+    connect(scoringPointCheckbox,SIGNAL(toggled(bool)),this,SLOT(slotToggleAdvancedSettings()));
 
     //the language code/name
-    KConfig entry(KStandardDirs::locate("locale", "all_languages"));
-    QString code = KanagramSettings::dataLanguage();
-    KConfigGroup group = entry.group(code);
+    QLocale languageLocale(KanagramSettings::dataLanguage());
+
     // select the current language
-    languageComboBox->setCurrentIndex(languageComboBox->findText(group.readEntry("Name")));
+    languageComboBox->setCurrentIndex(languageComboBox->findText(languageLocale.nativeLanguageName()));
+
+    // Connect after we set the current language from settings.
+    connect(languageComboBox, SIGNAL(currentIndexChanged(int)), this, SIGNAL(widgetModified()));
 }
 
 MainSettings::~MainSettings()
 {
 }
 
-void MainSettings::slotSetDirty()
-{
-    m_parent->enableButtonApply(true);
-}
-
 void MainSettings::slotToggleAdvancedSettings()
 {
-    textCorrectAnswer->setVisible(scoringOptions->isChecked());
-    kcfg_correctAnswerScore->setVisible(scoringOptions->isChecked());
-    textIncorrectAnswer->setVisible(scoringOptions->isChecked());
-    kcfg_incorrectAnswerScore->setVisible(scoringOptions->isChecked());
-    textRevealAnswer->setVisible(scoringOptions->isChecked());
-    kcfg_revealAnswerScore->setVisible(scoringOptions->isChecked());
-    textSkippedWord->setVisible(scoringOptions->isChecked());
-    kcfg_skippedWordScore->setVisible(scoringOptions->isChecked());
+    bool enable = scoringPointCheckbox->isChecked();
+    textCorrectAnswer->setVisible(enable);
+    kcfg_correctAnswerScore->setVisible(enable);
+    textIncorrectAnswer->setVisible(enable);
+    kcfg_incorrectAnswerScore->setVisible(enable);
+    textRevealAnswer->setVisible(enable);
+    kcfg_revealAnswerScore->setVisible(enable);
+    textSkippedWord->setVisible(enable);
+    kcfg_skippedWordScore->setVisible(enable);
 }
 
 void MainSettings::populateLanguageBox()
@@ -75,14 +75,13 @@ void MainSettings::populateLanguageBox()
     QStringList languages = SharedKvtmlFiles::languages();
 
     //the language code/name
-    KConfig entry(KStandardDirs::locate("locale", "all_languages"));
-    for (int i = 0; i < languages.count(); ++i) 
+    for (int i = 0; i < languages.count(); ++i)
     {
-        KConfigGroup group = entry.group(languages[i]);
-        
+        QLocale languageLocale(languages[i]);
+
         // get the language name
-        QString languageName = group.readEntry("Name");
-        if (languageName.isEmpty())
+        QString languageName = languageLocale.nativeLanguageName();
+        if (languageName.isEmpty() || languageName == "C")
         {
             languageName = i18nc("@item:inlistbox no language for that locale", "None");
         }
@@ -90,15 +89,15 @@ void MainSettings::populateLanguageBox()
     }
 }
 
-void MainSettings::slotUpdateLanguage()
+bool MainSettings::saveLanguage()
 {
     int index = languageComboBox->currentIndex();
     QString language = languageComboBox->itemData(index).toString();
-    kDebug() << "Writing new default language: " << language;
-    KanagramSettings::setDataLanguage(language);
-    KanagramSettings::self()->writeConfig();
-    
-    emit settingsChanged();
+    qCDebug(KANAGRAM) << "Writing new default language: " << language;
+    if (KanagramSettings::dataLanguage() != language) {
+        KanagramSettings::setDataLanguage(language);
+        KanagramSettings::self()->save();
+        return true;
+    }
+    return false;
 }
-
-#include "mainsettings.moc"
